@@ -2,20 +2,19 @@
 import os
 import sys
 from pathlib import Path
+from typing import Any, NoReturn
 
 import click
 from pygitguardian import GGClient
 
 from .ci import ci_cmd
-from .config import CONTEXT_SETTINGS, Config
+from .config import CONTEXT_SETTINGS, Config, load_dot_env
 from .dev_scan import path_cmd, precommit_cmd, range_cmd, repo_cmd
 from .filter import path_filter_set
 from .install import install
 
 
 @click.group(
-    invoke_without_command=True,
-    context_settings=CONTEXT_SETTINGS,
     commands={
         "commit-range": range_cmd,
         "pre-commit": precommit_cmd,
@@ -24,14 +23,6 @@ from .install import install
         "repo": repo_cmd,
     },
 )
-@click.option(
-    "--mode",
-    "-m",
-    type=click.Choice(["pre-commit", "ci"]),
-    help="Scan mode (pre-commit or ci)",
-    required=False,
-    hidden=True,
-)
 @click.option(
     "--show-secrets",
     is_flag=True,
@@ -59,7 +50,6 @@ from .install import install
 @click.pass_context
 def scan(
     ctx: click.Context,
-    mode: str,
     show_secrets: bool,
     exit_zero: bool,
     all_policies: bool,
@@ -91,26 +81,12 @@ def scan(
     if exit_zero is not None:
         ctx.obj["config"].exit_zero = exit_zero
 
-    if ctx.invoked_subcommand is None:
-        if mode:
-            click.echo(
-                "--mode has been deprecated and will be removed "
-                "after ggshield version 1.2. prefer to use subcommands."
-            )
-            if mode == "pre-commit":
-                return ctx.invoke(precommit_cmd)
-            elif mode == "ci":
-                return ctx.invoke(ci_cmd)
-            else:
-                click.echo(ctx.get_help())
-        else:
-            click.echo(ctx.get_help())
     return return_code
 
 
 @scan.resultcallback()
 @click.pass_context
-def exit_code(ctx: click.Context, exit_code: int, **kwargs):
+def exit_code(ctx: click.Context, exit_code: int, **kwargs: Any) -> None:
     """
     exit_code guarantees that the return value of a scan is 0
     when exit_zero is enabled
@@ -135,7 +111,8 @@ def exit_code(ctx: click.Context, exit_code: int, **kwargs):
     "--verbose", "-v", is_flag=True, default=None, help="Verbose display mode.",
 )
 @click.pass_context
-def cli(ctx: click.Context, config_path: str, verbose: bool):
+def cli(ctx: click.Context, config_path: str, verbose: bool) -> None:
+    load_dot_env()
     ctx.ensure_object(dict)
     if config_path:
         Config.CONFIG_LOCAL = [config_path]
@@ -147,5 +124,13 @@ def cli(ctx: click.Context, config_path: str, verbose: bool):
         ctx.obj["config"].verbose = verbose
 
 
+def cli_wrapper() -> NoReturn:
+    standalone_mode = not (
+        os.getenv("GITGUARDIAN_CRASH_LOG", "False").lower() == "true"
+    )
+    return_code = cli.main(standalone_mode=standalone_mode)
+    exit(return_code)
+
+
 if __name__ == "__main__":
-    cli()
+    cli_wrapper()
