@@ -1,22 +1,25 @@
+import concurrent.futures
 import os
 import tempfile
 import traceback
 from contextlib import contextmanager
 from pathlib import Path
-from typing import Iterable, List, Set
+from typing import Iterable, Iterator, List, Set
 
 import click
 from pygitguardian import GGClient
 
+from .config import CPU_COUNT, Config
 from .filter import path_filter_set
-from .git_shell import check_git_dir, get_list_all_commits, get_list_commit_SHA, shell
-from .message import process_results
+from .git_shell import check_git_dir, get_list_commit_SHA, is_git_dir, shell
+from .message import build_commit_info, process_results
 from .path import get_files_from_paths
 from .scannable import Commit
+from .utils import REGEX_GIT_URL
 
 
 @contextmanager
-def cd(newdir):
+def cd(newdir: str) -> Iterator[None]:
     prevdir = os.getcwd()
     os.chdir(os.path.expanduser(newdir))
     try:
@@ -25,31 +28,23 @@ def cd(newdir):
         os.chdir(prevdir)
 
 
-@click.command()
-@click.argument("repository", nargs=1, type=click.STRING, required=True)
-@click.pass_context
-def repo_cmd(ctx: click.Context, repository: str) -> int:  # pragma: no cover
-    """
-    clone and scan a REPOSITORY.
-
-    REPOSITORY is the clone URI of the repository to scan.
-    example:
-    ggshield scan repo git@github.com:GitGuardian/gg-shield.git
-    """
-    config = ctx.obj["config"]
+def scan_repo_path(
+    client: GGClient, config: Config, repo_path: str
+) -> int:  # pragma: no cover
     try:
-        with tempfile.TemporaryDirectory() as tmpdirname:
-            shell(["git", "clone", repository, tmpdirname])
-            with cd(tmpdirname):
-                return scan_commit_range(
-                    client=ctx.obj["client"],
-                    commit_list=get_list_all_commits(),
-                    verbose=config.verbose,
-                    filter_set=path_filter_set(Path(os.getcwd()), []),
-                    matches_ignore=config.matches_ignore,
-                    all_policies=config.all_policies,
-                    show_secrets=config.show_secrets,
-                )
+        with cd(repo_path):
+            if not is_git_dir():
+                raise click.ClickException(f"{repo_path} is not a git repository")
+
+            return scan_commit_range(
+                client=client,
+                commit_list=get_list_commit_SHA("--all"),
+                verbose=config.verbose,
+                filter_set=path_filter_set(Path(os.getcwd()), []),
+                matches_ignore=config.matches_ignore,
+                all_policies=config.all_policies,
+                show_secrets=config.show_secrets,
+            )
     except click.exceptions.Abort:
         return 0
     except Exception as error:
@@ -58,6 +53,33 @@ def repo_cmd(ctx: click.Context, repository: str) -> int:  # pragma: no cover
         raise click.ClickException(str(error))
 
 
+@click.command()
+@click.argument("repository", nargs=1, type=click.STRING, required=True)
+@click.pass_context
+def repo_cmd(ctx: click.Context, repository: str) -> int:  # pragma: no cover
+    """
+    scan a REPOSITORY at a given URL or path
+
+    REPOSITORY is the clone URI or the path of the repository to scan.
+    Examples:
+
+    ggshield scan repo git@github.com:GitGuardian/gg-shield.git
+
+    ggshield scan repo /repositories/gg-shield
+    """
+    config: Config = ctx.obj["config"]
+    client: GGClient = ctx.obj["client"]
+    if os.path.isdir(repository):
+        return scan_repo_path(client, config, repository)
+
+    if REGEX_GIT_URL.match(repository):
+        with tempfile.TemporaryDirectory() as tmpdirname:
+            shell(["git", "clone", repository, tmpdirname])
+            return scan_repo_path(client, config, tmpdirname)
+
+    raise click.ClickException(f"{repository} is neither a valid path nor a git URL")
+
+
 @click.command()
 @click.argument("commit_range", nargs=1, type=click.STRING)
 @click.pass_context
@@ -164,6 +186,27 @@ def path_cmd(
         raise click.ClickException(str(error))
 
 
+def scan_commit(
+    commit: Commit,
+    client: GGClient,
+    verbose: bool,
+    matches_ignore: Iterable[str],
+    all_policies: bool,
+    show_secrets: bool,
+) -> int:  # pragma: no cover
+    results = commit.scan(
+        client=client,
+        matches_ignore=matches_ignore,
+        all_policies=all_policies,
+        verbose=verbose,
+    )
+
+    if results or verbose:
+        click.echo(build_commit_info(commit))
+
+    return process_results(results=results, verbose=verbose, show_secrets=show_secrets)
+
+
 def scan_commit_range(
     client: GGClient,
     commit_list: List[str],
@@ -181,24 +224,21 @@ def scan_commit_range(
     :param verbose: Display successfull scan's message
     """
     return_code = 0
+    with concurrent.futures.ProcessPoolExecutor(max_workers=CPU_COUNT) as executor:
+        future_to_process = [
+            executor.submit(
+                scan_commit,
+                Commit(sha, filter_set),
+                client,
+                verbose,
+                matches_ignore,
+                all_policies,
+                show_secrets,
+            )
+            for sha in commit_list
+        ]
 
-    for sha in commit_list:
-        commit = Commit(sha, filter_set)
-        results = commit.scan(
-            client=client,
-            matches_ignore=matches_ignore,
-            all_policies=all_policies,
-            verbose=verbose,
-        )
-
-        if results or verbose:
-            click.echo("\nCommit {}:".format(sha))
-
-        return_code = max(
-            return_code,
-            process_results(
-                results=results, verbose=verbose, show_secrets=show_secrets,
-            ),
-        )
+        for future in concurrent.futures.as_completed(future_to_process):
+            return_code = max(return_code, future.result())
 
     return return_code
